==> sfn-paw-1.0.3.crate: sfn-paw-1.0.3/README.md <==
# sfn-paw
[![Current Crates.io Version](https://img.shields.io/crates/v/sfn-paw.svg)](https://crates.io/crates/sfn-paw)
![Release workflow](https://github.com/dawsonfi/paw/actions/workflows/rust.yml/badge.svg)

Step Functions CLI Tool

# Installation

In order to install this cli, run the following command:

`cargo install sfn-paw`

# Usage

Invoke the cli using the `sfn-paw` command.

## AWS Configuration

paw fetches the aws configuration from the `~/.aws/credentials` file, which should contain the following data:

* `region`
* `aws_access_key_id`
* `aws_secret_access_key`

for instructions see [AWS Configuration and credential file settings](https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html)

## Retry Failed Executions

1 - Select `Retry Failed Executions Action`

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_1.png)

2 - Select the desired Step Functions Machine

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_2.png)

3 - Input the Start Date (or leave it blank)

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_3.png)

4 - Input the End Date (or leave it blank)

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_4.png)

5 - Unmark any execution that you don't want to retry

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_5.png)

6 - Press enter to retry selected executions

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_6.png)

==> sfn-paw-1.0.5.crate: sfn-paw-1.0.5/README.md <==
<p align="center">
    <img align="left" src="https://raw.githubusercontent.com/dawsonfi/paw/main/dev/resources/logo.png" height="100px" alt="Cat Paw">
</p>

# PAW

Step Functions CLI Tool

<br />


[![Current Crates.io Version](https://img.shields.io/crates/v/sfn-paw.svg)](https://crates.io/crates/sfn-paw)
![Release workflow](https://github.com/dawsonfi/paw/actions/workflows/rust.yml/badge.svg)

# Installation

In order to install this cli, run the following command:

`cargo install sfn-paw`

# Usage

Invoke the cli using the `sfn-paw` command.

## AWS Configuration

paw fetches the aws configuration from the `~/.aws/credentials` file, which should contain the following data:

* `region`
* `aws_access_key_id`
* `aws_secret_access_key`

for instructions see [AWS Configuration and credential file settings](https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html)

## Retry Failed Executions

1 - Select `Retry Failed Executions Action`

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_1.png)

2 - Select the desired Step Functions Machine

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_2.png)

3 - Input the Start Date (or leave it blank)

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_3.png)

4 - Input the End Date (or leave it blank)

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_4.png)

5 - Unmark any execution that you don't want to retry

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_5.png)

6 - Press enter to retry selected executions

![Retry Failed Executions](https://raw.githubusercontent.com/dawsonfi/paw/assets/retry_failed_executions_6.png)
